======
region
======

The ``region`` module provides a polygon filling algorithm
used by ``skymatch`` to create data masks.

.. currentmodule:: romancal.skymatch.region

.. automodule:: romancal.skymatch.region
   :members:
   :undoc-members:
